;+
;
; .. interp_erai_t2m_1989_2009.pro:
;
; =============================
; interp_erai_t2m_1989_2009.pro
; =============================
;
;
;     .. graphviz::
;
;        digraph interp_erai_t2m_1989_2009 {
;           graph [
;           rankdir="LR",
;           ]
;           file_in [shape=ellipse,fontname=Courier,label="/Volumes/PRAVEEN/ERAI_global/20c3m_erai_t2_TROP_1989_2009.nc"];
;           mask [shape=ellipse,fontname=Courier,label="/Volumes/PRAVEEN/work/flux_reconstruction/gridded_data/mask_oaflux_30N30S.nc"];
;
;           ncfile [shape=ellipse,fontname=Courier,label="/Volumes/PRAVEEN/TropFlux/input_uncor/erai_t2m_19890101_20091231_oafluxgrid.nc"];
;
;           interp_erai_t2m_1989_2009 [shape=box,
;           fontname=Courier,
;           color=blue,
;           URL="http://forge.ipsl.jussieu.fr/tropflux/browser/trunk/src/interp_erai_t2m_1989_2009.pro"",
;           label="${TROPFLUX}/src/interp_erai_t2m_1989_2009.pro"];
;
;           {file_in mask} -> {interp_erai_t2m_1989_2009} -> {ncfile}
;
;          }
;
;
; SEE ALSO
; ========
;
; EXAMPLES
; ========
;
; ::
;
;  IDL> interp_erai_t2m_1989_2009
;
;
; TODO
; ====
;
; hard coded directory - usage of ${TROPFLUX_ID}
;
; coding rules
;
; EVOLUTIONS
; ==========
;
; - fplod 20101215T112140Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * add graph in header
;
; - fplod 20101214T093615Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * minimal header
;
; - pbk 2008
;
;   * creation
;
;-
pro interp_erai_t2m_1989_2009
@common

filein='/Volumes/PRAVEEN/ERAI_global/20c3m_erai_t2_TROP_1989_2009.nc'
gridout='/Volumes/PRAVEEN/work/flux_reconstruction/gridded_data/mask_oaflux_30N30S.nc'

initncdf, filein
domdef
latin=reform(gphit(0,*)) & lonin=reform(glamt(*,0))
print, 'lat grid ',min(latin),max(latin),latin(1)-latin(0)
print, 'lon grid ',min(lonin),max(lonin),lonin(1)-lonin(0)
t2min=read_ncdf("t2",19880101,20100930,file=filein,/nostr)

timein=time & jptin=jpt
tab=t2min(*,*,0)
mskin=glamt*0.+1.

initncdf, gridout
domdef
latout=reform(gphit(0,*)) & lonout=reform(glamt(*,0))
print, 'lat grid ',min(latout),max(latout),latout(1)-latout(0)
print, 'lon grid ',min(lonout),max(lonout),lonout(1)-lonout(0)
mskout=read_ncdf("msk", file=gridout,/nostr)

help, t2min,lonin,latin,mskin,lonout,latout,mskout
si=size(t2min)
t2mout=fltarr(jpi,jpj,jptin)
for jt=0,jptin-1 do begin
  print, 'Interpolation jt=',jt,' / ',jptin-1
  tab=reform(t2min(*,*,jt))
  t2mout(*,*,jt)=call_interp2d(tab,lonin,latin,mskin,lonout,latout,method='bilinear')
  t2mout(*,*,jt)=t2mout(*,*,jt)*mskout+(1.-mskout)*1.e20
endfor

timein=timein & jptin=jpt

initncdf, gridout
help, t2mout
tt=timein
time=julday(1,1,1989)+lindgen(7670)+0.5 & jpt=n_elements(time)
;cda0=string(jul2date(time(0)),format='(i8.8)')
;cda1=string(jul2date(time(jpt-1)),format='(i8.8)')
;cda0=string('19890101') & cda1=string('20091231')

timein=time-julday(1,1,1950,00,00)

lat=latout
lon=lonout
ncfile='!/Volumes/PRAVEEN/TropFlux/input_uncor/erai_t2m_19890101_20091231_oafluxgrid.nc'
lon_attr={units:'degrees_east',long_name:'Longitude'}
lat_attr={units:'degrees_north',long_name:'Latitude'}
time_attr={units:'hours since 1950-01-01 00:00:00',long_name:'Time axis',time_origin:' 1950-JAN-01 00:00:00'}
t2m_attr={units:'degK',missing_value:1e20,long_name:'Air Temperature at 2m',short_name:'t2m',axis:'TYX'}
globattr={source:'Data are from ECMWF ERA-Interim reanalysis', timerange:cda0+' - '+cda1}


ncfields = 't2m[longitude,latitude,time]=t2mout:t2m_attr; ' $
                      + 'longitude[]=lon:lon_attr; ' $
                      + 'latitude[]=lat:lat_attr; ' $
		      + 'time[*time]=timein:time_attr ' $
                      + ' @ globattr'

@ncdf_quickwrite


end
